summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2019-08-11 18:43:40 +0200
committerJulien Nabet <serval2412@yahoo.fr>2019-08-12 11:05:34 +0200
commit5e224c4223a1c0cc37314296da3d34c1f4cda9e4 (patch)
tree0ee498ef5339af13ddbc4416a01a8915c256b674
parentFix typos (diff)
downloadcore-5e224c4223a1c0cc37314296da3d34c1f4cda9e4.tar.gz
core-5e224c4223a1c0cc37314296da3d34c1f4cda9e4.zip
Fix typos
Change-Id: I32866c297c4df22cd8ad2f68bbadacea0042117e Reviewed-on: https://gerrit.libreoffice.org/77290 Tested-by: Jenkins Reviewed-by: Julien Nabet <serval2412@yahoo.fr>
-rw-r--r--sd/source/filter/ppt/pptanimations.hxx2
-rw-r--r--sd/source/ui/docshell/docshel4.cxx2
-rw-r--r--sd/source/ui/framework/configuration/ChangeRequestQueueProcessor.hxx2
-rw-r--r--sd/source/ui/framework/configuration/ConfigurationController.cxx2
-rw-r--r--sd/source/ui/func/fudraw.cxx2
-rw-r--r--sd/source/ui/func/fupoor.cxx2
-rw-r--r--sd/source/ui/func/fusel.cxx4
-rw-r--r--sd/source/ui/func/futext.cxx4
-rw-r--r--sd/source/ui/inc/ClientView.hxx2
-rw-r--r--sd/source/ui/inc/DrawController.hxx6
10 files changed, 14 insertions, 14 deletions
diff --git a/sd/source/filter/ppt/pptanimations.hxx b/sd/source/filter/ppt/pptanimations.hxx
index f9d5fa5479a3..84d168bfaf43 100644
--- a/sd/source/filter/ppt/pptanimations.hxx
+++ b/sd/source/filter/ppt/pptanimations.hxx
@@ -152,7 +152,7 @@ const sal_Int32 mso_Anim_Fill_REMOVE = 1;
const sal_Int32 mso_Anim_Fill_FREEZE = 2;
const sal_Int32 mso_Anim_Fill_HOLD = 3;
-/* constants for behaviour entry in PPtAnimationNode */
+/* constants for behaviour entry in PPTAnimationNode */
const sal_Int32 mso_Anim_Behaviour_FILTER = 24;
const sal_Int32 mso_Anim_Behaviour_ANIMATION= 25;
diff --git a/sd/source/ui/docshell/docshel4.cxx b/sd/source/ui/docshell/docshel4.cxx
index d9b9ff6e8e42..4def7ef0a1a6 100644
--- a/sd/source/ui/docshell/docshel4.cxx
+++ b/sd/source/ui/docshell/docshel4.cxx
@@ -732,7 +732,7 @@ void DrawDocShell::GotoBookmark(const OUString& rBookmark)
if (nPageNumber == SDRPAGE_NOTFOUND)
{
- // Is the bookmark a object?
+ // Is the bookmark an object?
pObj = mpDoc->GetObj(rBookmark);
if (pObj)
diff --git a/sd/source/ui/framework/configuration/ChangeRequestQueueProcessor.hxx b/sd/source/ui/framework/configuration/ChangeRequestQueueProcessor.hxx
index 17696fb25ce7..86a0324b409f 100644
--- a/sd/source/ui/framework/configuration/ChangeRequestQueueProcessor.hxx
+++ b/sd/source/ui/framework/configuration/ChangeRequestQueueProcessor.hxx
@@ -36,7 +36,7 @@ namespace sd { namespace framework {
class ConfigurationUpdater;
-/** The ChangeRequestQueueProcessor ownes the ChangeRequestQueue and
+/** The ChangeRequestQueueProcessor owns the ChangeRequestQueue and
processes the configuration change requests.
When after processing one entry the queue is empty then the
diff --git a/sd/source/ui/framework/configuration/ConfigurationController.cxx b/sd/source/ui/framework/configuration/ConfigurationController.cxx
index a78f18f1f2b1..d0d381d3032d 100644
--- a/sd/source/ui/framework/configuration/ConfigurationController.cxx
+++ b/sd/source/ui/framework/configuration/ConfigurationController.cxx
@@ -72,7 +72,7 @@ public:
std::shared_ptr<ConfigurationUpdater> mpConfigurationUpdater;
- /** The queue processor ownes the queue of configuration change request
+ /** The queue processor owns the queue of configuration change request
objects and processes the objects.
*/
std::unique_ptr<ChangeRequestQueueProcessor> mpQueueProcessor;
diff --git a/sd/source/ui/func/fudraw.cxx b/sd/source/ui/func/fudraw.cxx
index b6e915fdd052..5e319eafd260 100644
--- a/sd/source/ui/func/fudraw.cxx
+++ b/sd/source/ui/func/fudraw.cxx
@@ -778,7 +778,7 @@ bool FuDraw::SetHelpText(SdrObject* pObj, const Point& rPosPixel, const SdrViewE
This is used when a function gets a KEY_ESCAPE but can also
be called directly.
- @returns true if a active function was aborted
+ @returns true if an active function was aborted
*/
bool FuDraw::cancel()
{
diff --git a/sd/source/ui/func/fupoor.cxx b/sd/source/ui/func/fupoor.cxx
index da06f2add357..86d7233d69ea 100644
--- a/sd/source/ui/func/fupoor.cxx
+++ b/sd/source/ui/func/fupoor.cxx
@@ -1067,7 +1067,7 @@ void FuPoor::SwitchLayer (sal_Int32 nOffset)
This is used when a function gets a KEY_ESCAPE but can also
be called directly.
- @returns true if a active function was aborted
+ @returns true if an active function was aborted
*/
bool FuPoor::cancel()
{
diff --git a/sd/source/ui/func/fusel.cxx b/sd/source/ui/func/fusel.cxx
index bbfb1ab5f523..19fa3326e64c 100644
--- a/sd/source/ui/func/fusel.cxx
+++ b/sd/source/ui/func/fusel.cxx
@@ -784,7 +784,7 @@ bool FuSelection::MouseButtonUp(const MouseEvent& rMEvt)
{
if( rMEvt.IsRight() )
{
- // In watering-can mode, on press onto right mouse button, a undo is executed
+ // In watering-can mode, on press onto right mouse button, an undo is executed
mpViewShell->GetViewFrame()->GetDispatcher()->Execute( SID_UNDO, SfxCallMode::ASYNCHRON );
}
else if (pWaterCanCandidate != nullptr)
@@ -1274,7 +1274,7 @@ bool FuSelection::HandleImageMapClick(SdrObject* pObj, const Point& rPos)
This is used when a function gets a KEY_ESCAPE but can also
be called directly.
- @returns true if a active function was aborted
+ @returns true if an active function was aborted
*/
bool FuSelection::cancel()
{
diff --git a/sd/source/ui/func/futext.cxx b/sd/source/ui/func/futext.cxx
index 9c02439fadb5..c834fd3aa4c6 100644
--- a/sd/source/ui/func/futext.cxx
+++ b/sd/source/ui/func/futext.cxx
@@ -490,7 +490,7 @@ void FuText::ImpSetAttributesForNewTextObject(SdrTextObj* pTxtObj)
{
/* Create Impress text object (rescales to line height)
We get the correct height during the subsequent creation of the
- object, otherwise we draw to much */
+ object, otherwise we draw too much */
SfxItemSet aSet(mpViewShell->GetPool());
aSet.Put(makeSdrTextMinFrameHeightItem(0));
aSet.Put(makeSdrTextAutoGrowWidthItem(false));
@@ -1344,7 +1344,7 @@ SdrObjectUniquePtr FuText::CreateDefaultObject(const sal_uInt16 nID, const ::too
This is used when a function gets a KEY_ESCAPE but can also
be called directly.
- @returns true if a active function was aborted
+ @returns true if an active function was aborted
*/
bool FuText::cancel()
{
diff --git a/sd/source/ui/inc/ClientView.hxx b/sd/source/ui/inc/ClientView.hxx
index a616a6252bce..793e3b639449 100644
--- a/sd/source/ui/inc/ClientView.hxx
+++ b/sd/source/ui/inc/ClientView.hxx
@@ -36,7 +36,7 @@ public:
OutputDevice* pOutDev);
virtual ~ClientView() override;
- /* if the view should not do a Invalidate() on the windows, you have to
+ /* if the view should not do an Invalidate() on the windows, you have to
override the following two methods and do something different */
virtual void InvalidateOneWin(OutputDevice& rWin) override;
virtual void InvalidateOneWin(OutputDevice& rWin, const ::tools::Rectangle& rRect) override;
diff --git a/sd/source/ui/inc/DrawController.hxx b/sd/source/ui/inc/DrawController.hxx
index 8486a14e63cf..f4ad577093c1 100644
--- a/sd/source/ui/inc/DrawController.hxx
+++ b/sd/source/ui/inc/DrawController.hxx
@@ -235,7 +235,7 @@ private:
::std::vector< css::beans::Property>& rProperties);
/**
* The same as getFastProperyValue, but return the value through
* rValue and nHandle is always valid.
*/
virtual void SAL_CALL getFastPropertyValue(
@@ -251,7 +251,7 @@ private:
@param rOldValue
The old value. Only set if return is true.
@param nHandle
- The handle of the proberty.
+ The handle of the property.
@return
<TRUE/> if the value is converted successfully.
@throws IllegalArgumentException
@@ -262,7 +262,7 @@ private:
sal_Int32 nHandle,
const css::uno::Any& rValue ) override;
/** The same as setFastProperyValue, but no exception is thrown and nHandle
is always valid. You must not broadcast the changes in this method.
*/
virtual void SAL_CALL setFastPropertyValue_NoBroadcast(
@@ -235,7 +235,7 @@ private:
::std::vector< css::beans::Property>& rProperties);
/**
- * The same as getFastProperyValue, but return the value through
+ * The same as getFastPropertyValue, but return the value through
* rValue and nHandle is always valid.
*/
@@ -262,7 +262,7 @@ private:
sal_Int32 nHandle,
const css::uno::Any& rValue ) override;
- /** The same as setFastProperyValue, but no exception is thrown and nHandle
+ /** The same as setFastPropertyValue, but no exception is thrown and nHandle
is always valid. You must not broadcast the changes in this method.
*/